#
# spec file for package gmime2_6
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name gmime
%bcond_without mono
Name:           gmime2_6
Version:        2.6.23
Release:        lp151.3.3
Summary:        MIME Parser and Utility Library
License:        LGPL-2.1-or-later
Group:          Productivity/Networking/Email/Utilities
URL:            http://spruce.sourceforge.net/gmime/
Source:         http://download.gnome.org/sources/gmime/2.6/%{_name}-%{version}.tar.xz
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM gmime2_6-utf8.patch dimstar@opensuse.org -- Remove some non-ascii linebreaks
Patch0:         gmime2_6-utf8.patch
BuildRequires:  gobject-introspection-devel >= 1.30.0
BuildRequires:  gpgme-devel
BuildRequires:  gtk-doc
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(glib-2.0)
%if %{with mono}
BuildRequires:  mono-devel
BuildRequires:  pkgconfig(gapi-2.0)
BuildRequires:  pkgconfig(glib-sharp-2.0)
%endif

%description
GMime is a C/C++ library for parsing and creating messages using
the Multipurpose Internet Mail Extension (MIME).

%package -n libgmime-2_6-0
Summary:        MIME Parser and Utility Library
# The tools package was only for some sample applications, which are no longer installed since 2.6.5
Group:          System/Libraries
Obsoletes:      %{name}-tools < %{version}

%description -n libgmime-2_6-0
GMime is a C/C++ library for parsing and creating messages using
the Multipurpose Internet Mail Extension (MIME).

%package -n typelib-1_0-GMime-2_6
Summary:        MIME Parser and Utility Library -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-GMime-2_6
GMime is a C/C++ library for parsing and creating messages using
the Multipurpose Internet Mail Extension (MIME).

%if %{with mono}
%package sharp
Summary:        MIME Parser and Utility Library -- Mono Bindings
Group:          Development/Libraries/Other
Requires:       glib-sharp2
Requires:       libgmime-2_6-0 = %{version}
# Obsoletes without Provides: gmime-2_4-sharp was an old name
# during 2.4.x days, and even though API is different, we need to
# get rid of it since some files are common.
Obsoletes:      gmime-2_4-sharp < %{version}

%description sharp
GMime is a C/C++ library for parsing and creating messages using
the Multipurpose Internet Mail Extension (MIME).
%endif

%package devel
Summary:        MIME Parser and Utility Library -- Development Files
Group:          Development/Libraries/C and C++
Requires:       libgmime-2_6-0 = %{version}

%description devel
GMime is a C/C++ library for parsing and creating messages using
the Multipurpose Internet Mail Extension (MIME).

%define __find_requires env sh -c 'filelist=($(cat)) && { printf "%%s\\n" "${filelist[@]}" | %{_prefix}/lib/rpm/find-requires | grep -v "no package provides" ; } '

%prep
%setup -q -n %{_name}-%{version}
%patch0 -p1

%build
%ifarch %{arm}
# gcc has a bug on ARM where it fails to compile certain source files
# with >= -O2. See https://bugs.launchpad.net/gcc/+bug/836588.
CFLAGS="%{optflags} -O1"
%endif
%configure\
	--enable-largefile\
	--disable-static\
	--enable-gtk-doc \
%if %{with mono}
        --enable-mono \
%else
        --disable-mono \
%endif
        --with-gacdir=%{_prefix}/lib
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
for FILE in COPYING ; do
    MD5SUM=$(md5sum $FILE | sed 's/ .*//')
    if test -f %{_datadir}/doc/licenses/md5/$MD5SUM ; then
        ln -sf %{_datadir}/doc/licenses/md5/$MD5SUM $FILE
    fi
done

%post -n libgmime-2_6-0 -p /sbin/ldconfig
%postun -n libgmime-2_6-0 -p /sbin/ldconfig

%files -n libgmime-2_6-0
# NEWS is empty
%license COPYING
%doc AUTHORS ChangeLog README TODO
%{_libdir}/*.so.*

%files -n typelib-1_0-GMime-2_6
%{_libdir}/girepository-1.0/GMime-2.6.typelib

%if %{with mono}
%files sharp
%dir %{_prefix}/lib/mono/gmime-sharp-2.6
%dir %{_prefix}/lib/mono/gac/gmime-sharp
%dir %{_prefix}/lib/mono/gac/gmime-sharp/2.6.0.0__2b75c2ad004c52e4
%{_prefix}/lib/mono/gmime-sharp-2.6/gmime-sharp.dll
%{_prefix}/lib/mono/gac/gmime-sharp/2.6.0.0__2b75c2ad004c52e4/gmime-sharp.dll
%{_prefix}/lib/mono/gac/gmime-sharp/2.6.0.0__2b75c2ad004c52e4/gmime-sharp.dll.config
%{_datadir}/gapi-2.0/gmime-api.xml
# devel file:
%{_libdir}/pkgconfig/gmime-sharp-2.6.pc
%endif

%files devel
%doc PORTING
%{_datadir}/gir-1.0/GMime-2.6.gir
%{_includedir}/gmime-2.6
%{_libdir}/*.so
%{_libdir}/pkgconfig/gmime-2.6.pc
%doc %{_datadir}/gtk-doc/html/gmime-2.6/

%changelog
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Oct 30 2017 dimstar@opensuse.org
- Add gmime2_6-utf8.patch: Remove non-ascii line breaks from source
  files. Allows to build gmime 2.6 with gtk-doc using python 3.
* Sun May 28 2017 zaitor@opensuse.org
- Rename package to gmime2_6, for compatability with packages not
  ready to use the new gmime 3.0 branch.
* Sat Jan 21 2017 zaitor@opensuse.org
- Update to version 2.6.23:
  + gmime-crypto-context: Fixed naming.
* Sun Dec 18 2016 dimstar@opensuse.org
- Update to version 2.6.22:
  + Updated Mono bindings.
* Mon Dec 12 2016 dimstar@opensuse.org
- Update to version 2.6.21:
  + New function to determine if a MIME part is an attachment or
    not.
  + Treat all character values >= 128 as url-safe (bgo#738583).
  + Bugs fixed: bgo#756270, bgo#760573, bgo#760681, bgo#761263.
* Mon Oct  3 2016 dimstar@opensuse.org
- Add baselibs.conf:
  + produce libgmime-2_6-0-32bit package, needed by
    libxplayer-plparser18-32bit.
* Fri Jul 15 2016 alarrosa@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Tue Mar 31 2015 dimstar@opensuse.org
- Add --enable-mono/--disable-mono to configure call, based on the
  build condition. This avoids random rebuild failures (outside
  OBS) if mono happens to be installed on the building system.
* Wed Feb 19 2014 zaitor@opensuse.org
- Update to version 2.6.20:
  + Improved performance by using a SIMD hack when scanning for the
    end of a line.
  + Don't clear the mime_part header stream unless we actually
    remove a header.
  + Only add nwritten to the total if we've written a MIME-Version
    header.
  + Unref the disposition.
  + Don't write out 2 spaces between the ':' and the first
    message-id (bgo#711305).
* Sun Oct 20 2013 zaitor@opensuse.org
- Update to version 2.6.19:
  + Custom writer for References headers so that individual msgid
    tokens do not get folded (bgo#709031).
  + Initialize the mutexes earlier (bgo#708818).
  + Fixed warnings for glib >= 2.35.1.
  + Minor code/comment cleanup.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 2.6.18:
  + Reset the content stream after writing it.
  + Fixed an ABR by passing in an inend parameter.
  + New convenience function that handles opening the file for you.
  + Fixed g_mime_message_set_reply_to to parse the reply_to string
    just like g_mime_message_set_sender() does so that the reply_to
    field can be guaranteed to be in UTF-8.
  + Updated API documentation for functions taking or returning
    strings to clarify whether the strings should be in
    UTF-8 or not.
  + Various fixups to get rid of warnings in mono/GMime.metadata.
  + Don't call g_type_init() if glib >= 2.35.1.
  + Properly deal with obsolete routing information.
* Thu Aug  8 2013 dimstar@opensuse.org
- Update to version 2.6.17:
  + If no Content-Type header exists and the parent is a
    multipart/digest, default to message/rfc822 instead of
    text/plain.
  + If the Content-Type header didn't exist, use the default
    content-type values instead of assuming text/plain.
  + According to Rfc2046 Section 5.1.1, boundary markers may
    optionally be followed by lwsp (bgo#705612).
  + Fixed to properly handle a 0-byte substream at the end of the
    very last source stream (bgo#701572).
* Wed Jul  3 2013 dimstar@opensuse.org
- Update to version 2.6.16:
  + rfc2047_encode: Respect the new
    GMIME_ENABLE_USE_ONLY_USER_CHARSETS initialization flag.
  + New internal function that replaces the older header_fold()
    function. This new one uses the rfc2047 tokenizer so that we
    share the same rfc2047 workaround logic in the tokenizer
    (bgo#697407).
  + Disable g_warnings unless warnings are enabled in the build.
- Add gobject-introspection-devel BuildRequires in order to build
  the introspected bindings.
- Split typelib in typelib-1_0-GMime-2_6 subpackage.
* Sat Mar 16 2013 dmueller@suse.com
- add buildconditional for being able to build without mono
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 2.6.15:
  + gmime/gmime-filter-html.c (html_convert): Fixed to convert the
    last line of input even if it doesn't end with a \n.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 2.6.14:
  + Fixed the logic to actually scan for the beginning of the
    mailbox.
* Mon Dec 10 2012 dimstar@opensuse.org
- Update to version 2.6.13:
  + g_mime_header_iter_{first,last}: Make sure the list isn't
    empty.
  + g_mime_header_list_prepend: Prepend the header to the list,
    don't *append* it. Oops.
  + g_mime_header_list_clear: Don't forget to reset the linked list
    so that it doesn't contained free'd nodes.
* Mon Nov  5 2012 dimstar@opensuse.org
- Update to version 2.6.12:
  + stream_read): Initialize presize to READ_PAD instead of
    READ_SIZE to prevent potential buffer underruns.
  + unzip_filter: Apparently Z_BUF_ERROR isn't actually an error
    unless there is input available.
  + parser_push_boundary: Don't use strcmp to check if the boundary
    is an mbox boundary, use a direct pointer comparison so that we
    can handle Content-Type boundary parameters with a value of
    "From "
  + parser_step_headers: Don't assume that the first non-header
    line we find indicates the start of the content unless we've
    already gotten some basic headers (bgo#686223).
* Fri Oct 19 2012 zaitor@opensuse.org
- Update to version 2.6.11:
  + Misc fixes.
  + Bugs fixed: bgo#679388, bgo#674032.
* Mon Jun 18 2012 dimstar@opensuse.org
- Update to version 2.6.10:
  + Build fixes.
  + Bugs fixed: bgo#676692, bgo#677088, bgo#676341.
* Mon Apr 23 2012 dimstar@opensuse.org
- Update to version 2.6.9:
  + Properly handle application/x-pkcs7-signature (bgo#674032)
- Changes from version 2.6.8:
  + Bugs fixed: bgo#671785, bgo#673493.
* Sat Mar 10 2012 zaitor@opensuse.org
- Update to version 2.6.7:
  + Remove the trailing comma from the last enum item to silence
    gcc -pedantic warnings.
  + Be lenient from "From " lines found in message headers.
    (bgo#671680).
* Thu Mar  1 2012 cfarrell@suse.com
- license update: LGPL-2.1+
  Reduced to applicable license in SPDX format
* Tue Feb 21 2012 dimstar@opensuse.org
- Update to version 2.6.6:
  + configure.ac: Add a --enable-smime flag which defaults to "no".
  + Fixed multipart/signed logic.
  + Handle non-standard Content-Transfer-Encodings names: 7-bit,
    8-bit, and x-uue (the standard names for these are 7bit, 8bit,
    and x-uuencode).
  + Various other code changes.
  + Several optimizations.
* Sat Feb 18 2012 dimstar@opensuse.org
- Update to version 2.6.5:
  + Stop installing uuencode/uudecode.
  + configure.ac: Added --with-gacdir to fix bgo#667072
  + Several other build fixes.
  + Bug fixes, including: bgo#667684, bgo#668085.
- Drop tools subpackage: those are not really usable programs, but
  are meant as examples (they moved to the examples folder in the
  source code). Add a gmime-tools Obsoletes to libgmime-2_6-0 for
  smooth upgrades.
- Pass --with-gacdir=%%{_prefix}/lib to configure.
- Drop patches:
  + gmime-mono-arch-indep.patch: fixed upstream by introducing
  - -with-gacdir option to configure
  + gmime-compiler-warnings.patch: fixed upstream
- Remove libtool BuildRequires and call to autoreconf, as they were
  only needed by the patches,
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Thu Jan 12 2012 vuntz@opensuse.org
- The binaries shipped in the tools subpackage are GPL-2.0+, so fix
  the license of this subpackage. Fix bnc#741054.
* Wed Jan 11 2012 dimstar@opensuse.org
- Update to version 2.6.4:
  + GMime 2.6.x is ABI/API incompatible to GMime 2.4.x.
  + Most notable is the lack of GMimeSession which has been
    dropped in favor of a much simpler callback mechanism.
    GMimeCipherContexts constructors now take a password_request
    callback function rather than forcing you to subclass
    GMimeSession to get this functionality.
  + Several other API changes, see documentation.
  + See ChangeLog for full details since 2.4.x.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Add gpgme-devel BuildRequires: new upstream dependency.
- Add gmime-compiler-warnings.patch: Fix compiler warnings and brp
  checks about function reach end of statement without return
  value.
- Add gmime-mono-arch-indep.patch: Revert commit bce1443e321a2: we
  do not install mono libraries to %%{_libdir}, but %%{_prefix}/lib/
- Add libtool BuildRequires and call to autoreconf, as the above
  patch touches the build system.
- Rename libgmime-2_4-2 subpackage to libgmime-2_6-0, following the
  upstream soname bump.
- Remove gmime-2_4-devel and gmime-2_4-doc Provides/Obsoletes from
  devel subpackage: with 2.6, all files are now different in this
  package.
- Remove gmime-2_4-sharp Provides from sharp subpackage: since 2.6
  has a different API, a Provides is wrong. We keep the Obsoletes,
  though, as there are some common files and the gmime-2_4-sharp
  packages should get removed anyway.
* Tue Dec 20 2011 agraf@suse.com
- Compile with -O1 on ARM to work around gcc bug
* Sun Nov  6 2011 dimstar@opensuse.org
- Update to version 2.4.28:
  + Don't forget to register GMimeDataWrapper as well.
  + Need to decode the content of the application/octet-stream part
    containing the encrypted payload as it may have a non-7bit
    Content-Transfer-Encoding.
- Changes from version 2.4.27:
  + Register all GObject-based types to prevent race conditions in
    multi-threaded apps.
* Tue Aug  9 2011 dimstar@opensuse.org
- Update to version 2.4.26:
  + Don't skip validation of UTF-8 text.
  + Improved logic.
  + Bugs fixed: bgo#652056
* Mon Jul  4 2011 vuntz@opensuse.org
- Rename gmime-2_4 source package to gmime, overwriting the old
  gmime source package that was tracking the now unused 2.2.x
  branch (bnc#635094).
- Update to version 2.4.25:
  + Fix a crash.
  + Fix for MacOS X.
- Changes from version 2.4.24:
  + Fix PGP/MIME signature verification (broken in 2.4.23).
  + Depend on glib-sharp instead of gtk-sharp.
  + Documentation fixes.
- Changes from version 2.4.23:
  + Fixes for EXPSIG, EXPKEYSIG, and REVKEYSIG gpg status.
  + Documentation fixes.
- Changes from version 2.4.22:
  + Fixed memory stream writes.
- Remove gtk-sharp2 BuildRequires.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: glib2-devel, glib-sharp2, gtk-sharp2-gapi.
  + New ones: glib-2.0, glib-sharp-2.0, gapi-2.0.
- Remove explicit Requires for glib2-devel and glibc-devel in devel
  subpackage.
- Remove now unneeded Requires for gtk-sharp2 in sharp subpackage.
- Remove Conflicts with gmime < 2.4 as we now provide this.
- Merge doc subpackage in devel subpackage, and add appropriate
  Provides/Obsoletes.
- Create a tools subpackage, and move the binaries from the main
  subpackage to this new tools subpackage.
- Add Provides/Obsoletes for old names (before renaming) to the
  tools subpackage, the sharp and the devel subpackages.
- Change group of libgmime-2_4-2 from Development/Libraries/C and
  C++ to System/Libraries.
- Drop call to autoreconf: there's nothing requiring it.
- Update summaries and descriptions.
* Wed Dec 15 2010 vuntz@opensuse.org
- Update to version 2.4.21:
  + Do not write to filesystem when checking a GPG signature.
  + Make error messages more consistent.
  + When decoding an address, handle edge cases where inptr reaches
    the end of the input string prematurely due to a malformed
    address.
  + Code fixes.
- Changes from version 2.4.20:
  + When encoding, if the last input character is not a \n, append
    an "=\n" sequence.
  + Fixes for when there's no end marker.
  + Drop support for iso-2022-kr, and use euc-kr instead.
  + Code fixes.
* Tue Sep 14 2010 vuntz@opensuse.org
- Update to version 2.4.19:
  + Handle unquoted boundary values containing '=' (and other
    illegal characters).
  + Implement rfc2047-workaround hack in
    g_mime_utils_header_decode_phrase(), like in
    g_mime_utils_header_decode_text().
  + Keep track of the number of ='s that are backed out over in
    g_mime_encoding_base64_decode_step().
  + Fix crash when a group name is unset in InternetAddress.
  + Fix build with old glib (2.12).
- Changes from version 2.4.18:
  + Fix abusive unref in g_mime_multipart_encrypted_decrypt().
  + Internal rework of setting a name on InternetAddress.
* Sun Aug 22 2010 dimstar@opensuse.org
- Update to version 2.4.17:
  + gmime/gmime-encodings.h (GMIME_QP_ENCODE_LEN): Since
    force-wrapped lines use "=\n" instead of just "\n", lines will
    be 74 bytes, not 73.
- Changes from version 2.4.16:
  + Fixed to take into acount the possibility of having to
    force-wrap lines at 72+ characters.
  + bgo#615685: Added a --disable-cryptography flag to allow
    building without GnuPG or S/MIME support.
  + bgo#615594: Use g_set_error_literal() when no printf-style
    arguments are needed
  + bgo#598855: Mime-Version header re-written to MIME-Version.
* Fri Feb 12 2010 vuntz@opensuse.org
- Update to version 2.4.15:
  + Prevent possible buffer overflows.
- Changes from version 2.4.14:
  + Disable strict-aliasing since it cause bugs.
- Changes from version 2.4.13:
  + bgo#606875 -do not try to skip multiple characters per pass
    thru the loop when encountering the first '.' of a possible
    '..' sequence.
- Changes from version 2.4.12:
  + Moved -lz -lnsl, etc into Libs.private in pkg-config file
    (bgo#603273).
  + Make sure to always increment inptr as we force-convert it to
    ascii.
- Changes from version 2.4.11:
  + Fixed the military timezone offsets.
  + Fix ptr_array_insert() code to correctly work.
- Changes from version 2.4.10:
  + Fixed a uudecoding bug when uulen %% 3 is 2 (bgo#597794).
- Changes from version 2.4.9:
  + Fixed the target library version in gmime-sharp.dll.config.
* Fri Dec 18 2009 crrodriguez@opensuse.org
- Remove unneeded zlib-devel Requires in devel subpackage.
* Fri Aug 14 2009 sbrabec@suse.cz
- Updated to version 2.4.8:
  * Fixed possible buffer overrun in charset conversion code.
  * Compilation on systems with older GLib installations.
  * Cross-compilation simplified.
* Tue Aug  4 2009 sbrabec@suse.cz
- Removed unneeded Requires.
* Wed Jul  1 2009 sbrabec@suse.cz
- Split package for the new branch.
- Updated to version 2.4.7:
  * Major rewrite, new API. See ChangeLog for details.
* Fri Oct 17 2008 sbrabec@suse.cz
- Updated to version 2.2.23:
  * documentation updated
  * New faster method for calculating nearest power of 2.
  * New functions backported from 2.3.x:
    g_mime_parser_get_headers_begin, g_mime_parser_get_headers_end
  * Only ref the message if it is non-NULL.
- Fixed failure in mono binding installation.
* Fri Aug 15 2008 sbrabec@suse.cz
- Updated to version 2.2.22:
  * Bug fixes.
  * Memory leak fix.
  * See ChangeLog for more.
* Tue Apr  1 2008 sbrabec@suse.cz
- Updated to version 2.2.18:
  * Bug fixes.
  * New minor features.
  * Completely rewritten rfc2047_encode_merge_rfc822_words.
  * See ChangeLog for more.
- Ported off_t removal patches.
* Mon Mar 31 2008 sbrabec@suse.cz
- Fixed C# ABI corruption in gmime-no-off_t-api.patch (bnc#375195).
* Mon Jan 21 2008 ro@suse.de
- work around problem in mono-find-requires if the sharp bindings
  are a subpackage of the one providing the library
* Wed Dec  5 2007 sbrabec@suse.cz
- Removed off_t from the API. Fixes weird CFLAGS forcing gmime's
  off_t size to packages using gmime (#344662, GNOME#501830).
* Mon Nov 19 2007 sbrabec@suse.cz
- Updated to version 2.2.11:
  * Conditional for building with large file support.
  * 64-bit compatibility improvements.
  * Changed the license to LGPLv2.
  * Minor fixes and improvements.
* Tue Sep 25 2007 joeshaw@suse.de
- Add a patch to fix the Mono bindings when GMime is built with
  large file support.  (bnc #327589)
* Wed Aug  8 2007 sbrabec@suse.cz
- Fixed dependencies to allow to install more instances of library.
* Tue Aug  7 2007 ro@suse.de
- remove devel dependencies from library package
* Mon Aug  6 2007 sbrabec@suse.cz
- Updated to version 2.2.10:
  * Implemented a conditional workaround for broken rfc2047
    encodings.
- Enabled large file support and broken rfc2047 workaround.
- Split package according to shared library policy.
- Package gmime-sharp separately.
* Mon Jul 16 2007 sbrabec@suse.cz
- Fixed licenses linking.
* Sun Jul 15 2007 aj@suse.de
- Build sharp files again.
* Fri Jul 13 2007 sbrabec@suse.cz
- Updated to version 2.2.9:
  * New functions.
  * Bug fixes.
  * Memory leak fixes.
* Fri Mar 30 2007 rguenther@suse.de
- Add zlib-devel BuildRequires
* Fri Feb 16 2007 mvaner@suse.cz
- Compare strings properly, not as pointers, bug #225721
  - stdin-cmp.patch
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Tue Feb  6 2007 sbrabec@suse.cz
- Reduced BuildRequires.
* Wed Jan 10 2007 sbrabec@suse.cz
- Spec file cleanup.
* Tue Jan  9 2007 joeshaw@suse.de
- Clean up BuildRequires
* Sun Jan  7 2007 ro@suse.de
- GNOME moved to /usr
* Fri Oct 20 2006 sbrabec@suse.cz
- Update to version 2.2.3:
  * Decode the values for Subject, From, Reply-To.
  * Code imporvements.
  * Bug fixes.
* Sun Oct 15 2006 schwab@suse.de
- Make sure config.rpath is present.
* Fri Mar 17 2006 joeshaw@suse.de
- Update to version 2.2.1.  This contains a fix for reading mbox
  files in the middle of the last message, which would cause a
  tight CPU loop.  Fixes bnc #156916 and probably also #156927.
* Thu Feb 16 2006 joeshaw@suse.de
- Update the official tarball from 2.1.18 to 2.1.19.  There are
  actually no changes to the code at all, since the (now removed)
  backported patch contained all the differences between 2.1.18
  and 2.1.19.  This just makes already fixed bugs like bnc 147515
  a lot easier to spot.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 21 2006 joeshaw@suse.de
- Added a patch which backports an important fix from 2.1.19 to
  2.1.18.
* Fri Jan 13 2006 gekker@suse.de
- Fixup nfb and requires for new gtk-sharp2-packaging
- Fixup filelist
* Fri Jan 13 2006 joeshaw@suse.de
- Updated to version 2.1.18
* Tue Jan 10 2006 sbrabec@suse.cz
- Updated to version 2.1.17.
* Sun Sep  4 2005 aj@suse.de
- build as non-root.
- Add check-build.sh.
* Fri Aug 19 2005 gekker@suse.de
- Updated to version 2.1.16
- Require gtk-sharp2
* Tue Jul 12 2005 sbrabec@suse.cz
- Updated to version 2.1.15.
* Mon Mar 14 2005 gekker@suse.de
- Add gmime-mono-leak.patch to fix memory leaks.
* Tue Mar  8 2005 gekker@suse.de
- Update to version 2.1.13
* Tue Feb  8 2005 ro@suse.de
- rename uu{en,de}code to avoid conflict with sharutils
  (taken from source-provided specfile)
* Sun Feb  6 2005 ro@suse.de
- gtk-doc docu back to /opt/gnome
* Fri Feb  4 2005 gekker@suse.de
- Update to version 2.1.11.
- Enable C# bindings, add deps to neededforbuild
- Change prefix to /usr, for mono to work
* Thu Jan  6 2005 sbrabec@suse.cz
- Updated to version 2.1.9.
* Fri Aug 20 2004 sbrabec@suse.cz
- Updated to unstable version 2.1.7, needed by balsa.
* Fri Aug 20 2004 ke@suse.de
- gmime-doc.patch: Switch to DocBook DTD 4.1; version 3.0 does not
  support QANDASET, etc; reported by Stanislav Brabec.
* Thu Aug 19 2004 sbrabec@suse.cz
- New SuSE package, version 2.0.14.
